Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(594)

Unified Diff: chrome/android/javatests/src/org/chromium/chrome/browser/payments/PaymentRequestMultiplePayerInfoDetailsTest.java

Issue 2413833002: PaymentRequest: Rename ContactInfo to PayerInfo.
Patch Set: test Created 4 years, 2 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/android/javatests/src/org/chromium/chrome/browser/payments/PaymentRequestMultiplePayerInfoDetailsTest.java
diff --git a/chrome/android/javatests/src/org/chromium/chrome/browser/payments/PaymentRequestMultipleContactDetailsTest.java b/chrome/android/javatests/src/org/chromium/chrome/browser/payments/PaymentRequestMultiplePayerInfoDetailsTest.java
similarity index 74%
rename from chrome/android/javatests/src/org/chromium/chrome/browser/payments/PaymentRequestMultipleContactDetailsTest.java
rename to chrome/android/javatests/src/org/chromium/chrome/browser/payments/PaymentRequestMultiplePayerInfoDetailsTest.java
index 7f1625004f9945f99b9a9643f6c4902f04af4c60..adf1487c88602635d9a3559b69bb10a69135568f 100644
--- a/chrome/android/javatests/src/org/chromium/chrome/browser/payments/PaymentRequestMultipleContactDetailsTest.java
+++ b/chrome/android/javatests/src/org/chromium/chrome/browser/payments/PaymentRequestMultiplePayerInfoDetailsTest.java
@@ -16,13 +16,13 @@ import java.util.concurrent.ExecutionException;
import java.util.concurrent.TimeoutException;
/**
* A payment integration test for a merchant that requests contact details and a user that has
* 5 contact detail options.
*/
-public class PaymentRequestMultipleContactDetailsTest extends PaymentRequestTestBase {
- public PaymentRequestMultipleContactDetailsTest() {
- // The merchant requests both a phone number and an email address.
- super("payment_request_contact_details_test.html");
+public class PaymentRequestMultiplePayerInfoDetailsTest extends PaymentRequestTestBase {
+ public PaymentRequestMultiplePayerInfoDetailsTest() {
+ // The merchant requests payer information.
+ super("payment_request_payer_info_details_test.html");
}
@Override
@@ -74,20 +74,22 @@ public class PaymentRequestMultipleContactDetailsTest extends PaymentRequestTest
}
/**
* Make sure the contact details suggestions are in the correct order and that only the top 4
* are shown. They should be ordered by frecency and complete contact details should be
* suggested first.
*/
@MediumTest
@Feature({"Payments"})
- public void testContactDetailsSuggestionOrdering()
+ public void testPayerInfoDetailsSuggestionOrdering()
throws InterruptedException, ExecutionException, TimeoutException {
triggerUIAndWait(mReadyToPay);
- clickInContactInfoAndWait(R.id.payments_section, mReadyForInput);
- assertEquals(4, getNumberOfContactDetailSuggestions());
- assertEquals("555 123-4567\nlisa@simpson.com", getContactDetailsSuggestionLabel(0));
- assertEquals("555 123-4567\nmaggie@simpson.com", getContactDetailsSuggestionLabel(1));
- assertEquals("bart@simpson.com", getContactDetailsSuggestionLabel(2));
- assertEquals("homer@simpson.com", getContactDetailsSuggestionLabel(3));
+ clickInPayerInfoAndWait(R.id.payments_section, mReadyForInput);
+ assertEquals(4, getNumberOfPayerInfoDetailSuggestions());
+ assertEquals("Lisa Simpson\n555 123-4567\nlisa@simpson.com",
+ getPayerInfoDetailsSuggestionLabel(0));
+ assertEquals("Maggie Simpson\n555 123-4567\nmaggie@simpson.com",
+ getPayerInfoDetailsSuggestionLabel(1));
+ assertEquals("Bart Simpson\nbart@simpson.com", getPayerInfoDetailsSuggestionLabel(2));
+ assertEquals("Homer Simpson\nhomer@simpson.com", getPayerInfoDetailsSuggestionLabel(3));
}
}
@@ -16,13 +16,13 @@ import java.util.concurrent.ExecutionException;
import java.util.concurrent.TimeoutException;
/**
- * A payment integration test for a merchant that requests contact details and a user that has
- * 5 contact detail options.
+ * A payment integration test for a merchant that requests payer information details and a user that
+ * has 5 payer information detail options.
*/
@@ -74,20 +74,22 @@ public class PaymentRequestMultipleContactDetailsTest extends PaymentRequestTest
}
/**
- * Make sure the contact details suggestions are in the correct order and that only the top 4
- * are shown. They should be ordered by frecency and complete contact details should be
- * suggested first.
+ * Make sure the payer information details suggestions are in the correct order and that only
+ * the top 4 are shown. They should be ordered by frecency and complete payer information
+ * details should be suggested first.
*/

Powered by Google App Engine
This is Rietveld 408576698